@@ -12,13 +12,13 @@
 # include "singularconfig.h"
 # include "misc/auxiliary.h"
 
+#if defined(HAVE_MPFR_H) && defined(HAVE_LIBMPFR)
 #define HAVE_SVD
+#endif
 
-#undef VERSION
-#define VERSION "4.1.2"
 #define SINGULAR_MAJOR_VERSION 4
-#define SINGULAR_MINOR_VERSION 1
-#define SINGULAR_SUB_VERSION 2
+#define SINGULAR_MINOR_VERSION 2
+#define SINGULAR_SUB_VERSION 1
 #define S_ROOT_DIR ""
 
 /*******************************************************************
@@ -58,6 +58,11 @@
 /* Define to use scanner when loading libraries */
 #define HAVE_LIBPARSER
 
+/* define for parallel processes with shared memory */
+#ifndef __CCYGWIN__
+#define HAVE_VSPACE 1
+#endif
+
 /*#define PROFILING*/
 #ifdef PROFILING
 #define PROFILER ,0,0
@@ -76,7 +81,7 @@
 #define ALIGN_8
 #endif
 
-#define SINGULAR_PATCHLEVEL 5
+#define SINGULAR_PATCHLEVEL 0
 #define SINGULAR_VERSION ((SINGULAR_MAJOR_VERSION*1000 + SINGULAR_MINOR_VERSION*100 + SINGULAR_SUB_VERSION*10)+SINGULAR_PATCHLEVEL)
 
 /*******************************************************************
